summaryrefslogtreecommitdiffstats
path: root/base/message_pump_glib_unittest.cc
diff options
context:
space:
mode:
authortfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-10 14:56:17 +0000
committertfarina@chromium.org <tfarina@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-01-10 14:56:17 +0000
commit91cae259b5ab51d378e36607150ab181452e1008 (patch)
tree1d0e47c83709fa2db576b1ccdeb47ab50ee772a7 /base/message_pump_glib_unittest.cc
parent3c1ed419955a381f04f3881c81b48e59594af3da (diff)
downloadchromium_src-91cae259b5ab51d378e36607150ab181452e1008.zip
chromium_src-91cae259b5ab51d378e36607150ab181452e1008.tar.gz
chromium_src-91cae259b5ab51d378e36607150ab181452e1008.tar.bz2
base: Update the calls from MessageLoop::Quit() to QuitWhenIdle().
Quit() is deprecated and we should switch to QuitWhenIdle(). BUG=131220 R=darin@chromium.org Review URL: https://chromiumcodereview.appspot.com/11794032 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@176082 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'base/message_pump_glib_unittest.cc')
-rw-r--r--base/message_pump_glib_unittest.cc10
1 files changed, 5 insertions, 5 deletions
diff --git a/base/message_pump_glib_unittest.cc b/base/message_pump_glib_unittest.cc
index e23cc1e..4b6b6d4 100644
--- a/base/message_pump_glib_unittest.cc
+++ b/base/message_pump_glib_unittest.cc
@@ -311,7 +311,7 @@ class ConcurrentHelper : public base::RefCounted<ConcurrentHelper> {
--task_count_;
}
if (task_count_ == 0 && event_count_ == 0) {
- MessageLoop::current()->Quit();
+ MessageLoop::current()->QuitWhenIdle();
} else {
MessageLoop::current()->PostTask(
FROM_HERE, base::Bind(&ConcurrentHelper::FromTask, this));
@@ -323,7 +323,7 @@ class ConcurrentHelper : public base::RefCounted<ConcurrentHelper> {
--event_count_;
}
if (task_count_ == 0 && event_count_ == 0) {
- MessageLoop::current()->Quit();
+ MessageLoop::current()->QuitWhenIdle();
} else {
injector_->AddEventAsTask(
0, base::Bind(&ConcurrentHelper::FromEvent, this));
@@ -353,7 +353,7 @@ TEST_F(MessagePumpGLibTest, TestConcurrentEventPostedTask) {
// We use the helper class above. We keep both event and posted task queues
// full, the helper verifies that both tasks and events get processed.
// If that is not the case, either event_count_ or task_count_ will not get
// to 0, and MessageLoop::Quit() will never be called.
scoped_refptr<ConcurrentHelper> helper = new ConcurrentHelper(injector());
// Add 2 events to the queue to make sure it is always full (when we remove
@@ -514,7 +514,7 @@ void TestGLibLoopInternal(EventInjector* injector) {
ASSERT_EQ(3, task_count);
EXPECT_EQ(4, injector->processed_events());
- MessageLoop::current()->Quit();
+ MessageLoop::current()->QuitWhenIdle();
}
void TestGtkLoopInternal(EventInjector* injector) {
@@ -549,7 +549,7 @@ void TestGtkLoopInternal(EventInjector* injector) {
ASSERT_EQ(3, task_count);
EXPECT_EQ(4, injector->processed_events());
- MessageLoop::current()->Quit();
+ MessageLoop::current()->QuitWhenIdle();
}
} // namespace
@@ -353,7 +353,7 @@ TEST_F(MessagePumpGLibTest, TestConcurrentEventPostedTask) {
// full, the helper verifies that both tasks and events get processed.
// If that is not the case, either event_count_ or task_count_ will not get
- // to 0, and MessageLoop::Quit() will never be called.
+ // to 0, and MessageLoop::QuitWhenIdle() will never be called.
scoped_refptr<ConcurrentHelper> helper = new ConcurrentHelper(injector());
// Add 2 events to the queue to make sure it is always full (when we remove